@@ -1,15 +1,17 @@
 /**
  * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
  *
- * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
- * in compliance with the License. You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software distributed under the License
- * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
- * or implied. See the License for the specific language governing permissions and limitations under
- * the License.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package org.italiangrid.voms.clients;
 
@@ -196,6 +198,9 @@ public class VomsProxyInit extends AbstractCLI {
       params.setSkipHostnameChecks(true);
     }
 
+    if (commandLineHasOption(ProxyInitOptions.ENABLE_LEGACY_PROTOCOL)) {
+      params.setEnableLegacyProtocol(true);
+    }
     return params;
 
   }
@@ -231,8 +236,9 @@ public class VomsProxyInit extends AbstractCLI {
 
   private List<String> fqansSanityChecks(List<String> fqans) {
 
-    for (String f : fqans)
+    for (String f : fqans) {
       VOMSFQANNamingScheme.checkSyntax(f);
+    }
 
     return fqans;
   }
