@@ -18,13 +18,13 @@ package org.italiangrid.voms.clients.util;
 import java.io.InputStream;
 import java.io.OutputStream;
 
-import org.bouncycastle.openssl.PasswordFinder;
+import eu.emi.security.authn.x509.helpers.PasswordSupplier;
 
 public class PasswordFinders {
 
   public static final String PROMPT_MESSAGE = "Enter GRID pass phrase for this identity:";
 
-  public static PasswordFinder getDefault() {
+  public static PasswordSupplier getDefault() {
 
     if (System.console() != null)
       return new ConsolePasswordFinder(PROMPT_MESSAGE);
@@ -32,18 +32,18 @@ public class PasswordFinders {
     return new InputStreamPasswordFinder(PROMPT_MESSAGE, System.in, System.out);
   }
 
-  public static PasswordFinder getConsolePasswordFinder() {
+  public static PasswordSupplier getConsolePasswordFinder() {
 
     return new ConsolePasswordFinder(PROMPT_MESSAGE);
   }
 
-  public static PasswordFinder getInputStreamPasswordFinder(InputStream is,
+  public static PasswordSupplier getInputStreamPasswordFinder(InputStream is,
     OutputStream os) {
 
     return new InputStreamPasswordFinder(PROMPT_MESSAGE, is, os);
   }
 
-  public static PasswordFinder getNoPromptInputStreamPasswordFinder(
+  public static PasswordSupplier getNoPromptInputStreamPasswordFinder(
     InputStream is, OutputStream os) {
 
     return new InputStreamPasswordFinder(null, is, os);
